==> alg-common-1.22.1-20191009.085457-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/ActivityInfoData.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 *功能描述 广告位下可投活动info
 * @author lijingzhe
 * @date 2019/9/3
 * @param
 * @return
 */
public class ActivityInfoData {

    /**
     * 活动id
     */
    long activityId;
    /**
     * 广告位id
     */
    long slotId;
    /**
     * 媒体id
     */
    long appId;
    /**
     * 创建时间
     */
    long createTime = 0;
    /**
     * 活动请求/访问次数
     */
    ActivityVal request;
    /**
     * 券点击次数
     */
    ActivityVal click;
    /**
     * 消耗(分)
     */
    ActivityVal cost;
    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    int subType = 0;
    /**
     * 活动类型
     */
    long activityType;


    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public ActivityVal getRequest() {
        return request;
    }

    public void setRequest(ActivityVal request) {
        this.request = request;
    }

    public ActivityVal getClick() {
        return click;
    }

    public void setClick(ActivityVal click) {
        this.click = click;
    }

    public ActivityVal getCost() {
        return cost;
    }

    public void setCost(ActivityVal cost) {
        this.cost = cost;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }
}

==> alg-common-1.25.2-20191210.034946-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/ActivityInfoData.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 *功能描述 广告位下可投活动info
 * @author lijingzhe
 * @date 2019/9/3
 * @param
 * @return
 */
public class ActivityInfoData {

    /**
     * 活动id
     */
    long activityId;
    /**
     * 广告位id
     */
    long slotId;
    /**
     * 媒体id
     */
    long appId;
    /**
     * 创建时间
     */
    long createTime = 0;
    /**
     * 活动请求/访问次数
     */
    ActivityVal request;
    /**
     * 券点击次数
     */
    ActivityVal click;
    /**
     * 消耗(分)
     */
    ActivityVal cost;
    /**
     * 落地页转化次数
     */
    ActivityVal effect;
    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    int subType = 0;
    /**
     * 活动类型
     */
    long activityType;


    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public ActivityVal getRequest() {
        return request;
    }

    public void setRequest(ActivityVal request) {
        this.request = request;
    }

    public ActivityVal getClick() {
        return click;
    }

    public void setClick(ActivityVal click) {
        this.click = click;
    }

    public ActivityVal getCost() {
        return cost;
    }

    public void setCost(ActivityVal cost) {
        this.cost = cost;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public ActivityVal getEffect() {
        return effect;
    }

    public void setEffect(ActivityVal effect) {
        this.effect = effect;
    }
}
